import sys
if sys.version_info < (3, 10):
    from importlib_resources import files
else:
    from importlib.resources import files
import operator
from argparse import ArgumentParser
import csv
import numpy as np
import platformdirs
from pathlib import Path
import urllib.request

appname = "my_project"
appauthor = "myself"
archiwum_url = "http://static.nbp.pl/dane/kursy/Archiwum/archiwum_tab_a_2024.csv"
archiwum_name = "archiwum_tab_a_2024.csv"

def print_currency_table():
    currency_table = files("my_project.data").joinpath("archiwum_tab_a_2024.csv").read_text(encoding="utf-8", errors="replace")
    print(currency_table)

def print_currency_table_maybe_download():
    currency_path = Path(platformdirs.user_cache_dir(appname, appauthor)) / archiwum_name
    currency_path.parent.mkdir(parents=True, exist_ok=True)
    if not currency_path.exists():
        urllib.request.urlretrieve(archiwum_url, currency_path)
    with open(currency_path, 'rt',errors="replace") as f:
        print(f.read())

def exchange_rate(date, currency_symbol):
    "Return exchange rate for `date` and currency `currency_symbol`."
    currency_table = files("my_project.data").joinpath("archiwum_tab_a_2024.csv").read_text(encoding="utf-8", errors="replace").splitlines()
    reader = csv.DictReader(currency_table, delimiter=";")
    for row in reader:
        print(row['data'], row['1USD'])
    return None

def exchange_rate_command():
    parser = ArgumentParser()
    parser.add_argument("date")
    parser.add_argument("symbol")
    args = parser.parse_args()

    return exchange_rate(args.date, args.symbol)

def run():
    parser = ArgumentParser(
        prog="hello-world", 
        description="Prints out hello, world!")
    parser.add_argument("name")
    parser.add_argument("date")
    args = parser.parse_args()

    print("Hello, {:s}!".format(args.name))
    print("Today is {:s}".format(args.date))

def calculator(op, arg1, arg2):
    try:
        func = {"+": operator.add,
                "-": operator.sub,
                "*": operator.mul,
                "/": operator.truediv}[op]
    except KeyError:
        print("Unknown arithmetic operation: {:s}".format(op))
        sys.exit(1)

    return func(arg1, arg2)

def calculator_cli():
    parser = ArgumentParser(
            prog="calculator",
            description="Perform arithmetic operations.")
    parser.add_argument("op")
    parser.add_argument("arg1", type=float)
    parser.add_argument("arg2", type=float)
    args = parser.parse_args()

    print("{:f} {:s} {:f} = {:f}".format(
        args.arg1, args.op, args.arg2, 
        calculator(args.op, args.arg1, args.arg2)))
